"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validate = exports.DEFAULT_SCHEMA_VERSION = exports.SchemaVersion = exports.SchemaError = void 0;
const fs = require("fs");
const ajv = require("ajv");
const typed_error_1 = require("typed-error");
class SchemaError extends typed_error_1.TypedError {
}
exports.SchemaError = SchemaError;
var SchemaVersion;
(function (SchemaVersion) {
    SchemaVersion["v1"] = "";
    SchemaVersion["v2"] = "2.4";
})(SchemaVersion = exports.SchemaVersion || (exports.SchemaVersion = {}));
exports.DEFAULT_SCHEMA_VERSION = SchemaVersion.v2;
const schemas = {};
schemas[SchemaVersion.v1] = 'v1';
schemas[SchemaVersion.v2] = 'v2.4';
function loadJSON(path) {
    const filePath = require.resolve(path);
    const buf = fs.readFileSync(filePath);
    return JSON.parse(buf.toString('utf-8'));
}
function loadSchema(version) {
    return loadJSON(`./config_schema_${schemas[version]}.json`);
}
function validate(version, data) {
    const schema = loadSchema(version);
    const validator = new ajv({
        allErrors: false,
        coerceTypes: true,
        jsonPointers: true,
        logger: false,
        schemaId: 'id',
        useDefaults: true,
    });
    validator
        .addMetaSchema(loadJSON('ajv/lib/refs/json-schema-draft-04.json'))
        .addFormat('ports', validatePorts)
        .addFormat('expose', validateExpose)
        .addFormat('duration', validateDuration);
    if (!validator.validate(schema, data)) {
        throw new SchemaError(validator.errorsText());
    }
}
exports.validate = validate;
function validatePorts(value) {
    return /^(?:(?:([a-fA-F\d.:]+):)?([\d]*)(?:-([\d]+))?:)?([\d]+)(?:-([\d]+))?(?:\/(udp|tcp))?$/.test(value);
}
function validateExpose(value) {
    return /^\d+(\-\d+)?(\/[a-zA-Z]+)?$/.test(`${value}`);
}
function validateDuration(value) {
    if (typeof value === 'number') {
        return true;
    }
    const re = new RegExp('^' +
        '(?:([\\d.]+)h)?' +
        '(?:([\\d.]+)m)?' +
        '(?:([\\d.]+)s)?' +
        '(?:([\\d.]+)ms)?' +
        '(?:([\\d.]+)us)?' +
        '(?:([\\d.]+)ns)?' +
        '$');
    return re.test(value);
}
//# sourceMappingURL=index.js.map